abctools.ContextManager
=======================

.. abjad-lineage:: abjad.tools.abctools.ContextManager.ContextManager.ContextManager

.. autoclass:: abjad.tools.abctools.ContextManager.ContextManager.ContextManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__enter__
      ~abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__eq__
      ~abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__exit__
      ~abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__ne__
      ~abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__enter__
   :noindex:

.. automethod:: abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__eq__
   :noindex:

.. automethod:: abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__exit__
   :noindex:

.. automethod:: abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__ne__
   :noindex:

.. automethod:: abjad.tools.abctools.ContextManager.ContextManager.ContextManager.__repr__
   :noindex:
